<?php namespace EscapeWork\Manager\News\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\News\Repositories\NewsRepository;
use EscapeWork\Manager\News\Repositories\NewsCategoryRepository;
use EscapeWork\Manager\News\Models\News;
use View;
use Input;
use Redirect;
use Response;
use Request;
use Config;
use Msg;

class NewsController extends ManagerController
{

    public function __construct(NewsRepository $news, NewsCategoryRepository $newsCategory)
    {
        $this->news         = $news;
        $this->newsCategory = $newsCategory;

        # filters
        $this->enableDefaultFilters('news');
    }

    /**
    * Display a listing of the resource.
    *
    * @return Response
    */
    public function index()
    {
        $view = View::make(Config::get('manager-news::views.news.index'));
        $view->paramCategoryId = null;

        $params = Input::all();
        $query = $this->news->join('news_categories', 'news_categories.id', '=', 'news.news_category_id');

        # filtros
        if (isset($params['title']) && $params['title'] != '') {
            $query->where('news.title', 'like', '%'.$params['title'].'%');
        }

        if (isset($params['category_id']) && $params['category_id'] != '') {
            $query->orWhere('news_categories.id', '=', $params['category_id']);
            $view->paramCategoryId = $params['category_id'];
        }

        $query->select('news.*', 'news_categories.category');

        # ordenando os resultados (passar essa lógica pro model)
        $view->ordem  = 'desc';
        $view->icon   = null;
        $view->column = null;

        if (Input::has('col') && Input::has('ord')) {
            $view->column = Input::get('col');

            if (Input::get('ord') == 'desc')  {
                $view->ordem = 'asc';
                $view->icon = 'icon-chevron-up';
            }

            if (Input::get('ord') == 'asc') {
                $view->ordem = 'desc';
                $view->icon = 'icon-chevron-down';
            }

            if (Input::get('col') != 'category') {
                $query->orderBy('news.'.Input::get('col'), Input::get('ord'));
            } else {
                $query->orderBy('news_categories.'.Input::get('col'), Input::get('ord'));
            }
        } else {
            $query->orderBy('created_at', 'desc');
        }

        $view->news           = $query->paginate(20);
        $view->newsCategories = $this->newsCategory;

        return $view;
    }

    /**
    * Show the form for creating a new resource.
    *
    * @return Response
    */
    public function create()
    {
        $view = View::make(Config::get('manager-news::views.news.form'));

        $this->news->fill(Input::old());

        $view->news         = $this->news;
        $view->newsCategory = $this->newsCategory->get();
        $view->edit = false;

        return $view;
    }

    /**
    * Store a newly created resource in storage.
    *
    * @return Response
    */
    public function store()
    {
        $this->news->fill(Input::all());
        $this->news->date = date('Y-m-d', strtotime(str_replace('/', '-', $this->news->date)));
        if (! $this->news->validate()) {
            return Redirect::route('manager.noticias.create')
                        ->withInput()
                        ->with('errors', News::$messages );
        }

        $this->news->save();

        return Redirect::route('manager.noticias.index')->with('message', 'A notícia <strong>' . $this->news->title . '</strong> foi inserida com sucesso!');
    }

    /**
    * Show the form for editing the specified resource.
    *
    * @return Response
    */
    public function edit($id)
    {
        if (! $this->news = $this->news->find($id)) {
            return Redirect::route('manager.noticias.index')
                    ->with('error', 'Noticia não encontrada');
        }

        Msg::setInfo('Editando a noticia <strong>' . $this->news->title . '</strong>');

        $view                = View::make(Config::get('manager-news::views.news.form'));
        $view->news          = $this->news;
        $view->newsCategory  = $this->newsCategory->get();
        $view->edit = true;

        return $view;
    }

    /**
     * Salvando no banco de dados
     */
    public function update($id)
    {
        $this->news = $this->news->findOrFail($id);
        $this->news->fill(Input::all());

        if (! $this->news->validate()) {
            return Redirect::route('manager.noticias.edit', array($this->news->id))
                    ->withInput()
                    ->with('errors', News::$messages);
        }

        $this->news->save();

        return Redirect::to('manager/noticias')
                ->with('message', 'A notícia <strong>'.$this->news->title.'</strong> foi editada com sucesso!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @return Response
     */
    public function destroy($id)
    {
        $this->news = $this->news->findOrFail($id);
        $this->news->delete();

        return Redirect::route('manager.noticias.index')
                ->with('message', 'A notícia <strong>'.$this->news->title.'</strong> foi excluída com sucesso!');
    }

    /**
     * Atualizando se a noticia está ativa ou não
     */
    public function updateActive($id)
    {
        if (! $this->news = $this->news->find($id)) {
            return Response::json(array(
                'error' => 'Noticia não encontrada'
            ));
        }

        $this->news->active = Input::get('active');
        $this->news->save();

        return Response::json(array(
            'message' => 'A noticia foi atualizada com sucesso'
        ));
    }

    /**
     * Atualizando se a noticia é destaque ou não
     */
    public function updateFeatured($id)
    {
        if (! $this->news = $this->news->find($id)) {
            return Response::json(array(
                'error' => 'Noticia não encontrada'
            ));
        }

        $this->news->featured = Input::get('featured');
        $this->news->save();

        return Response::json(array(
            'message' => 'A noticia foi atualizada com sucesso'
        ));
    }

    /**
     * RSS de noticias
     */
    public function rss()
    {
        $view       = View::make(Config::get('manager-news::views.news.rss'));
        $view->news = $this->news->getLastNews(15);

        $response = Response::make($view->render());
        $response->header('Content-Type', 'text/xml; charset=utf-8');

        return $response;
    }
}
